function   [] = ComputeGMMs(dataBaseDir, modelBaseDir,  file_suffix, sampling_step, init_K, final_K,  canSkip)
% ComputeGMMs(dataBaseDir, modelBaseDir,  file_suffix, sampling_step, init_K, final_K,  canSkip)
% computes the image model by Gaussian mixture models (GMMs)
% 
% dataBaseDir:   the directory of image descriptors
% modelBaseDir:  the directory to store image models namely GMMs
% file_suffix:     the suffix of feature images
% sampling_step: the sampling step of descriptors to estimate GMMs
% init_K: the initial K
% final_K: the final K
% canSkip:      Flag whether we can skip if the descriptors have been computed
%
% Please cite the following paper if you use the code:
%
% Peihua Li,  Qilong Wang, Lei Zhang. A Novel Earth Mover's Distance Methodology for Image Matching with 
%Gaussian Mixture Models. IEEE Int. Conf. on Computer Vision (ICCV), 2013.
%
% For questions,  please conact:  Qilong Wang  (Email:  wangqilong.415@163.com), 
%                                               Peihua  Li (Email: peihuali at dlut dot edu dot cn) 
%                                               Lei zhang (Email: cslzhang  at comp dot polyu dot edu dot hk)
%
% The software is provided ''as is'' and without warranty of any kind,
% experess, implied or otherwise, including without limitation, any
% warranty of merchantability or fitness for a particular purpose.


fnames = dir(fullfile(dataBaseDir, sprintf('*%s', file_suffix)));
imageFileList = cell( length(fnames),1);
for f = 1: length(fnames)
    imageFileList{f} = fnames(f).name;
end


fprintf('Building image models --Processing %s', dataBaseDir);
for f =1:size(imageFileList,1)

    if ~mod(f, 5)
        fprintf('.');
    end
    
    curr_filename = imageFileList{f};

    suffix_pos = findstr(curr_filename, file_suffix);
    outFName = fullfile(modelBaseDir, [curr_filename(1:suffix_pos-1) '.mat']);
    if canSkip && size(dir(outFName), 1)
        continue;
    end

    dataFName = fullfile(dataBaseDir, curr_filename);
    load(dataFName, 'dataArr');
    
    features = cell(1,1);
  
    dataArrPart = dataArr(1:sampling_step:end,1:sampling_step:end,:);
    [g_y g_x bin] = size(dataArrPart);
    dataArrPart = reshape(dataArrPart,g_y*g_x,bin);
            
    [mtrs,omtr] = GaussianMixture(dataArrPart, init_K, final_K, false);
    omtr = post_one_gmm(omtr);

    features{1}= omtr.cluster;  

    dataArr = [];

    sp_make_dir(outFName);
    save(outFName, 'features');
end
fprintf('Completed.\n');

end