function inte_features = integralfeatures( im_features )
% inte_features = integralfeatures( im_features ) computes the integral
% images of input feature images. Through the integral images 
% we can compute efficiently the mean vector and covariance matrix of any patch of
% any size.
% 
% im_features: vector image each pixel point of which is an n-dimensional feature
% inte_features: integral images of  (n+n*(n+1)/2) layers, the first n
% layers are integral images of the original images, and the remaining
% layers are those of the component-product images.
%
% Please cite the following paper if you use the code:
%
%Peihua Li,  Qilong Wang: Local Log-Euclidean Covariance Matrix (L2ECM) for Image 
%Representation and Its Applications, (ECCV) 2012.
%
% For questions,  please conact:  Qilong Wang  (Email:  wangqilong.415@163.com), 
%                                               Peihua  Li (Email: peihuali at dlut dot edu dot cn) 
%
% The software is provided ''as is'' and without warranty of any kind,
% experess, implied or otherwise, including without limitation, any
% warranty of merchantability or fitness for a particular purpose.

[hgt wid n] = size(im_features);

layer = n + n*(n+1)/2;

inte_features1 = zeros(hgt, wid, layer);

inte_features1(:,:,1:n) = im_features(:,:,:);
layer_idx = n;

for i = 1 : n
    for j = i : n
        layer_idx = layer_idx + 1;
        inte_features1(:,:, layer_idx) = im_features(:,:,i) .* im_features(:,:,j);
    end
end

for i = 1 : layer
    inte_features1(:,:,i) = cumsum(inte_features1(:,:,i), 1);
    inte_features1(:,:,i) = cumsum(inte_features1(:,:,i), 2);
end


inte_features = zeros(hgt+1, wid+1, layer);
inte_features(2:end,2:end,:) = inte_features1(:,:,:);

end
            

 
  